@@ -1,8 +1,9 @@
 # Widget api is pretty ugly
+from django.conf import settings as django_settings
 from django.utils.datastructures import SortedDict
 from django.utils.safestring import mark_safe
 
-from sentry.settings import LOG_LEVELS
+from sentry import settings
 
 class Widget(object):
     def __init__(self, filter, request):
@@ -26,10 +27,11 @@ class ChoiceWidget(Widget):
         column = self.filter.get_query_param()
 
         output = ['<ul class="%s-list filter-list sidebar-module">' % (self.filter.column,)]
-        output.append('<li%(active)s><a href="%(query_string)s">Any %(label)s</a></li>' % dict(
+        output.append('<li%(active)s><a href="%(query_string)s&amp;%(column)s">Any %(label)s</a></li>' % dict(
             active=not value and ' class="active"' or '',
             query_string=query_string,
             label=self.filter.label,
+            column=column,
         ))
         for key, val in choices.iteritems():
             key = unicode(key)
@@ -117,9 +119,32 @@ class ServerNameFilter(SentryFilter):
     def get_query_set(self, queryset):
         return queryset.filter(message_set__server_name=self.get_value()).distinct()
 
+class SiteFilter(SentryFilter):
+    label = 'Site'
+    column = 'site'
+
+    def process(self, data):
+        if 'site' in data:
+            return data
+        if settings.SITE is None:
+            if 'django.contrib.sites' in django_settings.INSTALLED_APPS:
+                from django.contrib.sites.models import Site
+                try:
+                    settings.SITE = Site.objects.get_current().name
+                except Site.DoesNotExist:
+                    settings.SITE = ''
+            else:
+                settings.SITE = ''
+        if settings.SITE:
+            data['site'] = settings.SITE
+        return data
+
+    def get_query_set(self, queryset):
+        return queryset.filter(message_set__site=self.get_value()).distinct()
+
 class LevelFilter(SentryFilter):
     label = 'Level'
     column = 'level'
     
     def get_choices(self):
-        return SortedDict((str(k), v) for k, v in LOG_LEVELS)
\ No newline at end of file
+        return SortedDict((str(k), v) for k, v in settings.LOG_LEVELS)
\ No newline at end of file
