@@ -37,6 +37,8 @@ def get_db_engine(alias='default'):
 def construct_checksum(level=logging.ERROR, class_name='', traceback='', message='', **kwargs):
     checksum = md5_constructor(str(level))
     checksum.update(class_name or '')
+    if traceback:
+        traceback = '\n'.join(traceback.split('\n')[:-3])
     message = traceback or message
     if isinstance(message, unicode):
         message = message.encode('utf-8', 'replace')
